@@ -1,6 +1,7 @@
 from gevent.server import StreamServer
 from mprpc import RPCServer
 from spacy_api.api import single, bulk
+from spacy_api.client import BaseClient
 
 
 class SpacyServer(RPCServer):
@@ -13,14 +14,17 @@ class SpacyServer(RPCServer):
         return bulk(documents, model, embeddings_path, attributes)
 
 
-class SpacyLocalServer():
+class SpacyLocalServer(BaseClient):
 
-    def single(self, document, model="en", embeddings_path=None, attributes=None):
-        return single(document, model, embeddings_path, attributes)
+    def __init__(self, model, embeddings_path):
+        super(SpacyLocalServer, self).__init__(model, embeddings_path)
 
-    def bulk(self, documents, model="en", embeddings_path=None, attributes=None):
+    def single(self, document, attributes=None):
+        return single(document, self.model, self.embeddings_path, attributes, local=True)
+
+    def bulk(self, documents, attributes=None):
         documents = tuple(documents)
-        return bulk(documents, model, embeddings_path, attributes)
+        return bulk(documents, self.model, self.embeddings_path, attributes, local=True)
 
 
 def serve(host="127.0.0.1", port=9033):
@@ -28,5 +32,6 @@ def serve(host="127.0.0.1", port=9033):
     server = StreamServer((host, int(port)), SpacyServer())
     server.serve_forever()
 
+
 if __name__ == "__main__":
     serve()
